from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from voicegain_speech.api.aivr_callback_api import AivrCallbackApi
from voicegain_speech.api.aivr_ws_api import AivrWsApi
from voicegain_speech.api.asr_callback_api import AsrCallbackApi
from voicegain_speech.api.audiocodes_api import AudiocodesApi
from voicegain_speech.api.data_api import DataApi
from voicegain_speech.api.greg_api import GregApi
from voicegain_speech.api.meeting_api import MeetingApi
from voicegain_speech.api.recognize_api import RecognizeApi
from voicegain_speech.api.sa_api import SaApi
from voicegain_speech.api.sa_internal_api import SaInternalApi
from voicegain_speech.api.sa_offline_api import SaOfflineApi
from voicegain_speech.api.security_api import SecurityApi
from voicegain_speech.api.text_api import TextApi
from voicegain_speech.api.training_api import TrainingApi
from voicegain_speech.api.transcribe_api import TranscribeApi
from voicegain_speech.api.websocket_api import WebsocketApi
